@@ -606,8 +606,6 @@ print_implementation_info (GstElement * element)
   n_print ("\n");
   n_print ("Element Implementation:\n");
 
-  n_print ("  No loopfunc(), must be chain-based or not configured yet\n");
-
   n_print ("  Has change_state() function: %s\n",
       GST_DEBUG_FUNCPTR_NAME (gstelement_class->change_state));
 #ifndef GST_DISABLE_LOADSAVE
@@ -991,14 +989,16 @@ print_plugin_features (GstPlugin * plugin)
       if (factory->extensions) {
         guint i = 0;
 
-        g_print ("%s type: ", plugin->desc.name);
+        g_print ("%s: %s: ", plugin->desc.name,
+            gst_plugin_feature_get_name (feature));
         while (factory->extensions[i]) {
           g_print ("%s%s", i > 0 ? ", " : "", factory->extensions[i]);
           i++;
         }
         g_print ("\n");
       } else
-        g_print ("%s type: N/A\n", plugin->desc.name);
+        g_print ("%s: %s: no extensions\n", plugin->desc.name,
+            gst_plugin_feature_get_name (feature));
 
       num_types++;
     } else {
@@ -1118,9 +1118,6 @@ print_plugin_automatic_install_info_codecs (GstElementFactory * factory)
   klass = gst_element_factory_get_klass (factory);
   g_return_if_fail (klass != NULL);
 
-  if (strstr (klass, "Codec/") == NULL)
-    return;
-
   if (strstr (klass, "Demuxer") ||
       strstr (klass, "Decoder") ||
       strstr (klass, "Depay") || strstr (klass, "Parser")) {
@@ -1131,7 +1128,6 @@ print_plugin_automatic_install_info_codecs (GstElementFactory * factory)
     type_name = "encoder";
     direction = GST_PAD_SRC;
   } else {
-    g_printerr ("Unhandled Codec klass: %s\n", klass);
     return;
   }
 
